diff --git a/src/Microsoft.AspNetCore.ResponseCaching/ResponseCacheOptions.cs b/src/Microsoft.AspNetCore.ResponseCaching/ResponseCacheOptions.cs
index 795c80abcf..f530913fb9 100644
--- a/src/Microsoft.AspNetCore.ResponseCaching/ResponseCacheOptions.cs
+++ b/src/Microsoft.AspNetCore.ResponseCaching/ResponseCacheOptions.cs
@@ -9,9 +9,9 @@ namespace Microsoft.AspNetCore.Builder
public class ResponseCacheOptions
{
///
/// The largest cacheable size for the response body in bytes. The default is set to 1 MB.
///
- public long MaximumBodySize { get; set; } = 1024 * 1024;
+ public long MaximumBodySize { get; set; } = 64 * 1024 * 1024;
///
/// true if request paths are case-sensitive; otherwise false. The default is to treat paths as case-insensitive.
@@ -9,9 +9,9 @@ namespace Microsoft.AspNetCore.Builder
{
///
- /// The largest cacheable size for the response body in bytes. The default is set to 1 MB.
+ /// The largest cacheable size for the response body in bytes. The default is set to 64 MB.
///